@@ -12,7 +12,7 @@ import os
 import time
 import functools
 
-from lazyTest.file import YamlOperation, IniFileOperation, FileOperation, JsonFileOperation
+
 
 
 def Sleep(s: float = 1):
@@ -90,34 +90,6 @@ def ClearTestResult(path: str):
             ClearTestResult(path_file)
 
 
-def readElementSource(fileName: str) -> FileOperation:
-    """
-    根据文件后缀名创建对应的读取对象
-    """
-    if fileName != "" and fileName is not None:
-        if fileName.endswith(".yaml"):
-            return YamlOperation(fileName)
-        elif fileName.endswith(".json"):
-            return JsonFileOperation(fileName)
-        elif fileName.endswith(".ini"):
-            return IniFileOperation(fileName)
-        else:
-            raise Exception("文件类型错误")
 
 
-def writeElementKey(filepath, fileName, fileType, data: dict):
-    # 得到完整文件路径
-    realFile = filepath + fileName + fileType
-    if os.path.exists(realFile):
-        print("文件已存在不进行写入")
-    else:
-        newdata = {}
-        file = None
-        for i in data:
-            newdata[i.upper()] = data[i]
-        if fileType == '.yaml':
-            file = YamlOperation
-        elif fileType == '.json':
-            file = JsonFileOperation
-        file.writeFileToDict(realFile, newdata)
-        print("文件写入成功！！！")
+
